Index: media/audio/audio_parameters.h |
diff --git a/media/audio/audio_parameters.h b/media/audio/audio_parameters.h |
index b7b8ae507e3f75e2a91e90eed3d83e4ffad81c07..355c5e808d93237873f637099e73f810d6c46b38 100644 |
--- a/media/audio/audio_parameters.h |
+++ b/media/audio/audio_parameters.h |
@@ -24,15 +24,17 @@ struct AudioParameters { |
AudioParameters(); |
- AudioParameters(Format format, int channels, |
- int sample_rate, int bits_per_sample); |
+ AudioParameters(Format format, int channels, int sample_rate, |
+ int bits_per_sample, int samples_per_packet); |
bool IsValid() const; |
+ int GetPacketSize() const; |
scherkus (not reviewing)
2010/11/11 01:25:32
could you add some documentation to these two meth
Sergey Ulanov
2010/11/11 03:06:24
Done.
|
- Format format; // Format of the stream. |
- int channels; // Number of channels. |
- int sample_rate; // Sampling frequency/rate. |
- int bits_per_sample; // Number of bits per sample. |
+ Format format; // Format of the stream. |
+ int channels; // Number of channels. |
+ int sample_rate; // Sampling frequency/rate. |
+ int bits_per_sample; // Number of bits per sample. |
+ int samples_per_packet; // Size of a packet in frames. |
}; |
#endif // MEDIA_AUDIO_AUDIO_PARAMETERS_H_ |